Re-exports
pub use crate::value::EdgeRelation;pub use crate::value::HashKeyKind;
Structs
- Free
Cycle Stats - GcCollection
Report - GcObject
Summary - GcPhase
Stats - GcStats
Bundle - Diagnostics returned by
run_gc_with_stats_bundle: object catalog plus phase stats. - Global
Root - A global variable name and the object its slot references at report time. This is a present-tense fact read from the VM’s global table — the defined root set, not a guess about aliases.
- Heap
Snapshot - Object
Decision - Restoration
Witness - Scan
Stats - Trial
Deletion Stats - Visited
Edge